split_artifacts

Function split_artifacts 

pub fn split_artifacts(
    project: &Project,
    data_artifacts: &[ArtifactData],
    new_artifacts: &[ArtifactData],
    for_create: bool,
) -> Result<(HashMap<u64, ArtifactData>, Artifacts), Error>
split artifacts into artifacts which are unchanged and artifacts which are changed.

Also do lots of error checking and validation

If create flag is true, this is for the Create command (only expect new artifacts). Otherwise it is for the Update command (only expect artifacts that exist).