pub struct Name {
pub raw: String,
pub value: Vec<String>,
pub ty: Type,
}Expand description
Definition of an artifact name, with Traits for hashing, displaying, etc
Fields
raw: Stringuser definition
value: Vec<String>standardized version
ty: Typethe inferred type of the artifact
Implementations
Sourceimpl Name
impl Name
pub fn from_string(s: String) -> Result<Name>
Sourcepub fn parent(&self) -> Option<Name>
pub fn parent(&self) -> Option<Name>
parse name from string and handle errors see: SPC-artifact-name.2 see: SPC-artifact-partof-2
pub fn parent_rc(&self) -> Option<NameRc>
Sourcepub fn named_partofs(&self) -> Vec<Name>
pub fn named_partofs(&self) -> Vec<Name>
return the artifact this artifact is automatically a partof (because of it’s name) see: SPC-artifact-partof-1