FmtArtifact

Struct FmtArtifact 

pub struct FmtArtifact {
    pub long: bool,
    pub def: Option<PathBuf>,
    pub parts: Option<Vec<FmtArtifact>>,
    pub partof: Option<Vec<FmtArtifact>>,
    pub done: Option<String>,
    pub text: Option<String>,
    pub name: NameRc,
}
structure which contains all the information necessary to format an artifact for cmdline, html, or anything else purposely doesn’t contain items that are always displayed such as completed or tested

Fields

long: booldef: Option<PathBuf>parts: Option<Vec<FmtArtifact>>partof: Option<Vec<FmtArtifact>>done: Option<String>text: Option<String>name: NameRc

Implementations

Source

impl FmtArtifact

pub fn write<W: Write>( &self, w: &mut W, cwd: &Path, artifacts: &Artifacts, color: bool, indent: u8, ) -> Result<()>

write the formatted version of the artifact to the cmdline writter

#SPC-cmd-ls-color