pub struct UUID { /* private fields */ }Methods from Deref<Target = Uuid>
Sourcepub fn get_variant(&self) -> Option<UuidVariant>
pub fn get_variant(&self) -> Option<UuidVariant>
Returns the variant of the Uuid structure.
This determines the interpretation of the structure of the UUID. Currently only the RFC4122 variant is generated by this module.
Sourcepub fn get_version_num(&self) -> usize
pub fn get_version_num(&self) -> usize
Returns the version number of the Uuid.
This represents the algorithm used to generate the contents.
Currently only the Random (V4) algorithm is supported by this module. There are security and privacy implications for using older versions - see Wikipedia: Universally Unique Identifier for details.
Sourcepub fn get_version(&self) -> Option<UuidVersion>
pub fn get_version(&self) -> Option<UuidVersion>
Returns the version of the Uuid.
This represents the algorithm used to generate the contents
Sourcepub fn as_bytes(&self) -> &[u8; 16]
pub fn as_bytes(&self) -> &[u8; 16]
Return an array of 16 octets containing the UUID data
Examples
use uuid::Uuid;
let uuid = Uuid::nil();
assert_eq!(uuid.as_bytes(), &[0; 16]);
let uuid = Uuid::parse_str("936DA01F9ABD4d9d80C702AF85C822A8").unwrap();
assert_eq!(uuid.as_bytes(),
&[147, 109, 160, 31, 154, 189, 77, 157,
128, 199, 2, 175, 133, 200, 34, 168]);Sourcepub fn simple(&self) -> Simple<'_>
pub fn simple(&self) -> Simple<'_>
Returns a wrapper which when formatted via fmt::Display will format a
string of 32 hexadecimal digits.
Examples
use uuid::Uuid;
let uuid = Uuid::nil();
assert_eq!(uuid.simple().to_string(),
"00000000000000000000000000000000");Sourcepub fn hyphenated(&self) -> Hyphenated<'_>
pub fn hyphenated(&self) -> Hyphenated<'_>
Returns a wrapper which when formatted via fmt::Display will format a
string of hexadecimal digits separated into groups with a hyphen.
Examples
use uuid::Uuid;
let uuid = Uuid::nil();
assert_eq!(uuid.hyphenated().to_string(),
"00000000-0000-0000-0000-000000000000");Sourcepub fn urn(&self) -> Urn<'_>
pub fn urn(&self) -> Urn<'_>
Returns a wrapper which when formatted via fmt::Display will format a
string of the UUID as a full URN string.
Examples
use uuid::Uuid;
let uuid = Uuid::nil();
assert_eq!(uuid.urn().to_string(),
"urn:uuid:00000000-0000-0000-0000-000000000000");Sourcepub fn to_timestamp(&self) -> Option<(u64, u16)>
pub fn to_timestamp(&self) -> Option<(u64, u16)>
Returns an Optional Tuple of (u64, u16) representing the timestamp and counter portion of a V1 UUID. If the supplied UUID is not V1, this will return None