pub fn validate(repo: &Path, project: &Project) -> Result<()>
validate that all files that could be affected by the project are within the repo and the settings.artifact_paths partof: #SPC-security
settings.artifact_paths