pub struct FmtArtifact {
pub long: bool,
pub def: Option<PathBuf>,
pub parts: Option<Vec<FmtArtifact>>,
pub partof: Option<Vec<FmtArtifact>>,
pub done: Option<String>,
pub text: Option<String>,
pub name: NameRc,
}Expand description
structure which contains all the information necessary to format an artifact for cmdline, html, or anything else purposely doesn’t contain items that are always displayed such as completed or tested
Fields
long: booldef: Option<PathBuf>parts: Option<Vec<FmtArtifact>>partof: Option<Vec<FmtArtifact>>done: Option<String>text: Option<String>name: NameRcImplementations